@@ -1,5 +1,5 @@
 # Interface between GDB and Insight.
-# Copyright (C) 1997, 1998, 1999, 2001, 2002, 2004 Red Hat, Inc.
+# Copyright (C) 1997, 1998, 1999, 2001, 2002, 2004, 2008 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License (GPL) as published by
@@ -301,7 +301,7 @@ proc gdbtk_cleanup {} {
 # PROC: gdbtk_tcl_query -
 # ------------------------------------------------------------------
 proc gdbtk_tcl_query {message {default yes}} {
-  global gdb_checking_for_exit gdbtk_state tcl_platform
+  global gdb_checking_for_exit gdbtk_state gdbtk_platform
 
   # FIXME We really want a Help button here.  But Tk's brain-damaged
   # modal dialogs won't really allow it.  Should have async dialog
@@ -317,7 +317,7 @@ proc gdbtk_tcl_query {message {default yes}} {
     set modal "system"
   }
   
-  if {$tcl_platform(platform) == "windows"} {
+  if {$gdbtk_platform(platform) == "windows"} {
     # On Windows, we want to only ask each question once.
     # If we're already asking the question, just wait for the answer
     # to come back.
@@ -368,6 +368,8 @@ proc gdbtk_tcl_warning {message} {
 	"Internal error.*" { gdbtk_tcl_fputs_error $message }
         "incomplete CFI.*" { gdbtk_tcl_fputs_error $message }
 	"RTTI symbol not found for class.*" { gdbtk_tcl_fputs_error $message }
+        "DW_AT.*" { gdbtk_tcl_fputs_error $message }
+        "unsupported tag.*" { gdbtk_tcl_fputs_error $message }
         default {show_warning $message}
        }
 }
@@ -376,7 +378,7 @@ proc gdbtk_tcl_warning {message} {
 # PROC: show_warning -
 # ------------------------------------------------------------------
 proc show_warning {message} {
-  global tcl_platform
+  global gdbtk_platform
 
   # FIXME We really want a Help button here.  But Tk's brain-damaged
   # modal dialogs won't really allow it.  Should have async dialog
@@ -395,7 +397,7 @@ proc show_warning {message} {
 # another thread is not required.
 
  
-  if {$tcl_platform(platform) == "windows"} {
+  if {$gdbtk_platform(platform) == "windows"} {
       ide_messageBox [list set r] -icon warning \
         -default ok -message $message -title $title \
         -type ok -modal $modal -parent .
@@ -916,7 +918,7 @@ proc set_exe {} {
 # ------------------------------------------------------------------
 
 proc _open_file {{file ""}} {
-  global gdb_running gdb_downloading tcl_platform
+  global gdb_running gdb_downloading gdbtk_platform
   
   if {$gdb_running || $gdb_downloading} {
     # We are already running/downloading something..
@@ -962,7 +964,7 @@ proc _open_file {{file ""}} {
   }
   # Add the base dir for this file to the source search path.
   set root [file dirname $file]
-  if {$tcl_platform(platform) == "windows"} {
+  if {$gdbtk_platform(os) == "cygwin"} {
     set root [ide_cygwin_path to_posix $root]
     set file [ide_cygwin_path to_posix $file]
   }
@@ -1160,7 +1162,7 @@ necessary,\nmodify the port setting with the debugger preferences."
 proc run_executable { {auto_start 1} } {
   global gdb_loaded gdb_downloading gdb_target_name
   global gdb_exe_changed gdb_target_changed gdb_program_has_run
-  global gdb_running gdb_exe_name tcl_platform
+  global gdb_running gdb_exe_name gdbtk_platform
 
 #  debug "auto_start=$auto_start gdb_target_name=$gdb_target_name"
 
@@ -1256,7 +1258,7 @@ proc run_executable { {auto_start 1} } {
 
     # If the user requested it, start an xterm for use as the
     # inferior's tty.
-    if {$tcl_platform(platform) != "windows"
+    if {$gdbtk_platform(platform) != "windows"
 	&& [pref getd gdb/process/xtermtty] == "yes"} {
       tty::create
     }
@@ -1827,3 +1829,71 @@ proc gdbtk_console_read {} {
   debug "result=$result"
   return $result
 }
+
+# This is based on TIP 171 to enable better default behavior
+# with the MouseWheel event. I don't know why this is not in 
+# Tk yet (at least 8.5), but this allows all of our windows to
+# scroll without having to do anything.
+proc ::tk::MouseWheel {wFired X Y D {shifted 0}} {
+    # Set event to check based on call
+    set evt "<[expr {$shifted?{Shift-}:{}}]MouseWheel>"
+    # do not double-fire in case the class already has a binding
+    if {[bind [winfo class $wFired] $evt] ne ""} { return }
+    # obtain the window the mouse is over
+    set w [winfo containing $X $Y]
+    # if we are outside the app, try and scroll the focus widget
+    if {![winfo exists $w]} { catch {set w [focus]} }
+    if {[winfo exists $w]} {
+	if {[bind $w $evt] ne ""} {
+	    # Awkward ... this widget has a MouseWheel binding, but to
+	    # trigger successfully in it, we must give it focus.
+	    catch {focus} old
+	    if {$w ne $old} { focus $w }
+	    event generate $w $evt -rootx $X -rooty $Y -delta $D
+	    if {$w ne $old} { focus $old }
+	    return
+	}
+	# aqua and x11/win32 have different delta handling
+	if {[tk windowingsystem] ne "aqua"} {
+	    set delta [expr {- ($D / 30)}]
+	} else {
+	    set delta [expr {- ($D)}]
+	}
+	# scrollbars have different call conventions
+	if {[string match "*Scrollbar" [winfo class $w]]} {
+	    catch {tk::ScrollByUnits $w \
+		       [string index [$w cget -orient] 0] $delta}
+	} else {
+	    # Walking up to find the proper widget handles cases like
+	    # embedded widgets in a canvas
+
+	    # 20091008-keiths: This cannot possibly work the way it
+	    # was written in the TIP, so I've rewritten it to work the
+	    # way the comments say it should.
+	    set cmd [list "%W" [expr {$shifted ? "xview" : "yview"}] \
+			 scroll $delta units]
+	    while {[catch [regsub "%W" $cmd $w]] && [winfo toplevel $w] ne $w} {
+		set w [winfo parent $w]
+	    }
+	}
+    }
+}
+
+bind all <MouseWheel> [list ::tk::MouseWheel %W %X %Y %D 0]
+bind all <Shift-MouseWheel> [list ::tk::MouseWheel %W %X %Y %D 1]
+if {[tk windowingsystem] eq "x11"} {
+    # Support for mousewheels on Linux/Unix commonly comes through
+    # mapping the wheel to the extended buttons.
+    bind all <4> [list ::tk::MouseWheel %W %X %Y 120]
+    bind all <5> [list ::tk::MouseWheel %W %X %Y -120]
+}
+
+set mw_classes [list Text Listbox Table TreeCtrl]
+foreach class $mw_classes { bind $class <MouseWheel> {} }
+if {[tk windowingsystem] eq "x11"} {
+    foreach class $mw_classes {
+	 bind $class <4> {}
+	 bind $class <5> {}
+    }
+}
+
